@@ -1,6 +1,6 @@
 =begin
 = xmlrpc/client.rb
-Copyright (C) 2001 by Michael Neumann (neumann@s-direktnet.de)
+Copyright (C) 2001, 2002 by Michael Neumann (neumann@s-direktnet.de)
 
 Released under the same term of license as Ruby.
 
@@ -252,7 +252,7 @@ Note: Inherited methods from class (({Object})) cannot be used as XML-RPC names,
 
 
 = History
-    $Id: client.rb,v 1.47 2001/07/20 13:24:56 michael Exp $
+    $Id: client.rb,v 1.51 2003/04/08 15:14:22 mneumann Exp $
 
 =end
 
@@ -315,11 +315,11 @@ module XMLRPC
 
 
     def self.new2(uri, proxy=nil, timeout=nil)
-      if uri =~ /^([^:]+):\/\/(([^@]+)@)?([^\/]+)(\/.*)?$/
-        proto = $1
-        user, passwd = ($3 || "").split(":")
-        host, port = $4.split(":") 
-        path = $5
+      if match = uri.match(/^([^:]+):\/\/(([^@]+)@)?([^\/]+)(\/.*)?$/)
+        proto = match[1]
+        user, passwd = (match[3] || "").split(":")
+        host, port = match[4].split(":") 
+        path = match[5]
 
         if proto != "http" and proto != "https"
           raise "Wrong protocol specified. Only http or https allowed!"
@@ -341,7 +341,7 @@ module XMLRPC
       h = {}
       hash.each { |k,v| h[k.to_s.downcase] = v }
 
-      self.new(h['host'], h['path'], h['port'], h['proxy_port'], h['user'], h['password'],
+      self.new(h['host'], h['path'], h['port'], h['proxy_host'], h['proxy_port'], h['user'], h['password'],
                h['use_ssl'], h['timeout'])
     end
 
@@ -472,6 +472,8 @@ module XMLRPC
         header["Authorization"] = @auth
       end
  
+      resp = nil
+
       if async
         # use a new HTTP object for each call 
         Net::HTTP.version_1_2
@@ -479,15 +481,19 @@ module XMLRPC
         http.use_ssl = @use_ssl if @use_ssl
         http.read_timeout = @timeout
         http.open_timeout = @timeout
+        
+        # post request
+        http.start {
+          resp = http.post2(@path, request, header) 
+        }
       else
         # reuse the HTTP object for each call => connection alive is possible
-        http = @http
+        
+        # post request
+        resp = @http.post2(@path, request, header) 
       end
   
-      # post request
-      resp = http.post2(@path, request, header) 
       data = resp.body
-      http.finish if async
 
       if resp.code == "401"
         # Authorization Required
